FacebookPostResponse class

The class represents a response from a Facebook post request, including whether it was successful, a message, and the HTTP response.

Constructors

FacebookPostResponse({required bool isSuccess, required String message, Response? response})

Properties

hashCode int
The hash code for this object.
no setterinherited
isSuccess bool
final
message String
final
response → Response?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited