FacebookPostResponse class
The class represents a response from a Facebook post request, including whether it was successful, a message, and the HTTP response.
Constructors
- FacebookPostResponse({required bool isSuccess, required String message, Response? response})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited